@@ -104,8 +104,9 @@ class Assignments(BrowserView):
 
                 # and copy over the assignments
                 for id, assignment in mapping.items():
+                    assignment_copy=assignment._getCopy(assignment)
                     if not id in ids2:
-                        mapping2[id] = assignment
+                        mapping2[id] = assignment_copy
                         LOG.info('assigned portlet %s to %s' % (id, userid))
                         dashboards_updated[userid] = True
 
